@@ -7,11 +7,11 @@ use crate::{
 
 /// Provisions a register to put a variable in, and then adds the assembly used to initialize the
 /// variable to the end of the buffer.
-pub(crate) fn convert_variable_decl_to_asm<'sc>(
-    var_decl: &TypedVariableDeclaration<'sc>,
-    namespace: &mut AsmNamespace<'sc>,
+pub(crate) fn convert_variable_decl_to_asm(
+    var_decl: &TypedVariableDeclaration,
+    namespace: &mut AsmNamespace,
     register_sequencer: &mut RegisterSequencer,
-) -> CompileResult<'sc, Vec<Op<'sc>>> {
+) -> CompileResult<Vec<Op>> {
     let var_register = register_sequencer.next();
     let initialization =
         convert_expression_to_asm(&var_decl.body, namespace, &var_register, register_sequencer);
