@@ -1,9 +1,12 @@
 //! This is the flow graph, a graph which contains edges that represent possible steps of program
 //! execution.
 
-use crate::semantic_analysis::{ast_node::TypedStructField, TypedAstNode};
-use crate::span::Span;
-use crate::{semantic_analysis::ast_node::TypedEnumVariant, Ident};
+use crate::{
+    semantic_analysis::{ast_node::TypedEnumVariant, ast_node::TypedStructField, TypedAstNode},
+    Ident,
+};
+
+use sway_types::span::Span;
 
 use petgraph::{graph::EdgeIndex, prelude::NodeIndex};
 
@@ -15,7 +18,7 @@ pub type EntryPoint = NodeIndex;
 pub type ExitPoint = NodeIndex;
 
 #[derive(Clone, Default)]
-/// A graph that can be used to model the control flow of a fuel HLL program.
+/// A graph that can be used to model the control flow of a Sway program.
 /// This graph is used as the basis for all of the algorithms in the control flow analysis portion
 /// of the compiler.
 pub struct ControlFlowGraph {
