@@ -1,16 +1,12 @@
 //! Tools related to handling/recovering from Sway compile errors and reporting them to the user.
 
-use crate::ident::Ident;
-use crate::parser::Rule;
-use crate::span::Span;
-use crate::style::{to_screaming_snake_case, to_snake_case, to_upper_camel_case};
-use crate::type_engine::*;
-use crate::type_engine::{IntegerBits, TypeInfo};
-use line_col::LineColLookup;
-use source_span::{
-    fmt::{Formatter, Style},
-    Position,
+use crate::{
+    parser::Rule,
+    style::{to_screaming_snake_case, to_snake_case, to_upper_camel_case},
+    type_engine::*,
 };
+use sway_types::{ident::Ident, span::Span};
+
 use std::fmt;
 use thiserror::Error;
 
@@ -186,34 +182,6 @@ impl CompileWarning {
             self.span.end_pos().line_col().into(),
         )
     }
-
-    pub fn format(&self, fmt: &mut Formatter) -> source_span::fmt::Formatted {
-        let input = self.span.input();
-        let chars = input.chars().map(|x| -> Result<_, ()> { Ok(x) });
-
-        let metrics = source_span::DEFAULT_METRICS;
-        let buffer = source_span::SourceBuffer::new(chars, Position::default(), metrics);
-
-        for c in buffer.iter() {
-            let _ = c.unwrap(); // report eventual errors.
-        }
-
-        let (start_pos, end_pos) = self.span();
-        let lookup = LineColLookup::new(input);
-        let (start_line, start_col) = lookup.get(start_pos);
-        let (end_line, end_col) = lookup.get(end_pos - 1);
-
-        let err_start = Position::new(start_line - 1, start_col - 1);
-        let err_end = Position::new(end_line - 1, end_col - 1);
-        let err_span = source_span::Span::new(err_start, err_end, err_end.next_column());
-        fmt.add(
-            err_span,
-            Some(self.to_friendly_warning_string()),
-            Style::Warning,
-        );
-
-        fmt.render(buffer.iter(), buffer.span(), &metrics).unwrap()
-    }
 }
 
 #[derive(Debug, Clone, PartialEq, Hash)]
@@ -423,6 +391,11 @@ pub enum CompileError {
          code that triggered this error."
     )]
     Internal(&'static str, Span),
+    #[error(
+        "Internal compiler error: {0}\nPlease file an issue on the repository and include the \
+         code that triggered this error."
+    )]
+    InternalOwned(String, Span),
     #[error("Unimplemented feature: {0:?}")]
     UnimplementedRule(Rule, Span),
     #[error(
@@ -931,6 +904,7 @@ impl CompileError {
             ParseFailure { span, .. } => span,
             InvalidTopLevelItem(_, span) => span,
             Internal(_, span) => span,
+            InternalOwned(_, span) => span,
             UnimplementedRule(_, span) => span,
             InvalidByteLiteralLength { span, .. } => span,
             ExpectedExprAfterOp { span, .. } => span,
@@ -1040,32 +1014,4 @@ impl CompileError {
             self.internal_span().end_pos().line_col().into(),
         )
     }
-
-    pub fn format(&self, fmt: &mut Formatter) -> source_span::fmt::Formatted {
-        let input = self.internal_span().input();
-        let chars = input.chars().map(Result::<_, String>::Ok);
-
-        let metrics = source_span::DEFAULT_METRICS;
-        let buffer = source_span::SourceBuffer::new(chars, Position::default(), metrics);
-
-        for c in buffer.iter() {
-            let _ = c.unwrap(); // report eventual errors.
-        }
-
-        let (start_pos, end_pos) = self.span();
-        let lookup = LineColLookup::new(input);
-        let (start_line, start_col) = lookup.get(start_pos);
-        let (end_line, end_col) = lookup.get(if end_pos == 0 { 0 } else { end_pos - 1 });
-
-        let err_start = Position::new(start_line - 1, start_col - 1);
-        let err_end = Position::new(end_line - 1, end_col - 1);
-        let err_span = source_span::Span::new(err_start, err_end, err_end.next_column());
-        fmt.add(
-            err_span,
-            Some(self.to_friendly_error_string()),
-            Style::Error,
-        );
-
-        fmt.render(buffer.iter(), buffer.span(), &metrics).unwrap()
-    }
 }
