@@ -29,13 +29,14 @@ use pest::Parser;
 use std::collections::{HashMap, HashSet};
 use std::sync::Arc;
 
-pub use semantic_analysis::TreeType;
-pub use semantic_analysis::TypedParseTree;
+pub use semantic_analysis::{
+    create_module, retrieve_module, Namespace, NamespaceRef, NamespaceWrapper, TreeType,
+    TypedDeclaration, TypedFunctionDeclaration, TypedParseTree,
+};
 pub mod types;
 pub use crate::parse_tree::{Declaration, Expression, UseStatement, WhileLoop, *};
 
 pub use error::{CompileError, CompileResult, CompileWarning};
-pub use semantic_analysis::{Namespace, TypedDeclaration, TypedFunctionDeclaration};
 use sway_types::{ident::Ident, span};
 pub use type_engine::TypeInfo;
 
@@ -160,7 +161,7 @@ pub enum CompilationResult {
     },
     Library {
         name: Ident,
-        namespace: Box<Namespace>,
+        namespace: NamespaceRef,
         warnings: Vec<CompileWarning>,
     },
     Failure {
@@ -238,7 +239,7 @@ pub(crate) struct InnerDependencyCompileResult {
 /// clean up the types here with the power of hindsight
 pub(crate) fn compile_inner_dependency(
     input: Arc<str>,
-    initial_namespace: &Namespace,
+    initial_namespace: NamespaceRef,
     build_config: BuildConfig,
     dead_code_graph: &mut ControlFlowGraph,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
@@ -266,7 +267,8 @@ pub(crate) fn compile_inner_dependency(
     let typed_parse_tree = check!(
         TypedParseTree::type_check(
             parse_tree.tree,
-            initial_namespace.clone(),
+            initial_namespace,
+            initial_namespace,
             &parse_tree.tree_type,
             &build_config,
             dead_code_graph,
@@ -303,7 +305,7 @@ pub(crate) fn compile_inner_dependency(
 
 pub fn compile_to_ast(
     input: Arc<str>,
-    initial_namespace: &Namespace,
+    initial_namespace: crate::semantic_analysis::NamespaceRef,
     build_config: &BuildConfig,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
 ) -> CompileAstResult {
@@ -324,7 +326,8 @@ pub fn compile_to_ast(
     let typed_parse_tree = check!(
         TypedParseTree::type_check(
             parse_tree.tree,
-            initial_namespace.clone(),
+            initial_namespace,
+            initial_namespace,
             &parse_tree.tree_type,
             &build_config.clone(),
             &mut dead_code_graph,
@@ -360,7 +363,7 @@ pub fn compile_to_ast(
 /// form (not raw bytes/bytecode).
 pub fn compile_to_asm(
     input: Arc<str>,
-    initial_namespace: &Namespace,
+    initial_namespace: crate::semantic_analysis::NamespaceRef,
     build_config: BuildConfig,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
 ) -> CompilationResult {
@@ -394,7 +397,7 @@ pub fn compile_to_asm(
                 TreeType::Library { name } => CompilationResult::Library {
                     warnings,
                     name,
-                    namespace: Box::new(parse_tree.into_namespace()),
+                    namespace: parse_tree.get_namespace_ref(),
                 },
             }
         }
@@ -500,7 +503,7 @@ fn combine_constants(ir: &mut Context, functions: &[Function]) -> CompileResult<
 /// bytecode form.
 pub fn compile_to_bytecode(
     input: Arc<str>,
-    initial_namespace: &Namespace,
+    initial_namespace: crate::semantic_analysis::NamespaceRef,
     build_config: BuildConfig,
     dependency_graph: &mut HashMap<String, HashSet<String>>,
 ) -> BytecodeCompilationResult {
