@@ -1,9 +1,13 @@
-use crate::build_config::BuildConfig;
-use crate::parse_tree::{CallPath, Literal};
-use crate::Span;
-use crate::{error::*, AstNode, AstNodeContent, Declaration, VariableDeclaration};
-use crate::{parser::Rule, type_engine::TypeInfo};
-use crate::{CodeBlock, Ident};
+use crate::{
+    build_config::BuildConfig,
+    error::*,
+    parse_tree::{ident, CallPath, Literal},
+    parser::Rule,
+    type_engine::TypeInfo,
+    AstNode, AstNodeContent, CodeBlock, Declaration, VariableDeclaration,
+};
+
+use sway_types::{ident::Ident, join_spans, Span};
 
 use either::Either;
 use pest;
@@ -17,7 +21,6 @@ mod matcher;
 mod method_name;
 mod scrutinee;
 mod unary_op;
-use crate::utils::join_spans;
 pub(crate) use asm::*;
 pub(crate) use match_branch::MatchBranch;
 pub(crate) use match_condition::CatchAll;
@@ -390,12 +393,18 @@ impl Expression {
                     path: path.clone(),
                 };
                 let mut func_app_parts = expr.into_inner();
-                let name = check!(
-                    CallPath::parse_from_pair(func_app_parts.next().unwrap(), config),
+                let first_part = func_app_parts.next().unwrap();
+                assert!(first_part.as_rule() == Rule::ident);
+                let suffix = check!(
+                    ident::parse_from_pair(first_part, config),
                     return err(warnings, errors),
                     warnings,
                     errors
                 );
+                let name = CallPath {
+                    prefixes: vec![],
+                    suffix,
+                };
                 let (arguments, type_args) = {
                     let maybe_type_args = func_app_parts.next().unwrap();
                     match maybe_type_args.as_rule() {
@@ -455,7 +464,7 @@ impl Expression {
                     match pair.as_rule() {
                         Rule::var_name_ident => {
                             name = Some(check!(
-                                Ident::parse_from_pair(pair, config),
+                                ident::parse_from_pair(pair, config),
                                 Ident::new_with_override("error parsing var name", span.clone()),
                                 warnings,
                                 errors
@@ -522,7 +531,7 @@ impl Expression {
                 let mut expr_iter = expr.into_inner();
                 let struct_name = expr_iter.next().unwrap();
                 let struct_name = check!(
-                    Ident::parse_from_pair(struct_name, config),
+                    ident::parse_from_pair(struct_name, config),
                     return err(warnings, errors),
                     warnings,
                     errors
@@ -531,7 +540,7 @@ impl Expression {
                 let mut fields_buf = Vec::new();
                 for i in (0..fields.len()).step_by(2) {
                     let name = check!(
-                        Ident::parse_from_pair(fields[i].clone(), config),
+                        ident::parse_from_pair(fields[i].clone(), config),
                         return err(warnings, errors),
                         warnings,
                         errors
@@ -677,7 +686,7 @@ impl Expression {
                         //
                         // ["a", "b", "c", "add"]
                         let method_name = check!(
-                            Ident::parse_from_pair(name_parts.pop().unwrap(), config),
+                            ident::parse_from_pair(name_parts.pop().unwrap(), config),
                             return err(warnings, errors),
                             warnings,
                             errors
@@ -719,7 +728,7 @@ impl Expression {
                                     path: path.clone(),
                                 },
                                 field_to_access: check!(
-                                    Ident::parse_from_pair(name_part, config),
+                                    ident::parse_from_pair(name_part, config),
                                     continue,
                                     warnings,
                                     errors
@@ -744,7 +753,7 @@ impl Expression {
                                 Rule::path_separator => (),
                                 Rule::path_ident => {
                                     path_parts_buf.push(check!(
-                                        Ident::parse_from_pair(pair, config),
+                                        ident::parse_from_pair(pair, config),
                                         continue,
                                         warnings,
                                         errors
@@ -777,7 +786,7 @@ impl Expression {
                             call_path: CallPath {
                                 prefixes: path_parts_buf,
                                 suffix: check!(
-                                    Ident::parse_from_pair(
+                                    ident::parse_from_pair(
                                         method_name.expect("guaranteed by grammar"),
                                         config
                                     ),
@@ -903,7 +912,7 @@ impl Expression {
                             path: path.clone(),
                         },
                         field_to_access: check!(
-                            Ident::parse_from_pair(name_part, config),
+                            ident::parse_from_pair(name_part, config),
                             continue,
                             warnings,
                             errors
@@ -1123,7 +1132,7 @@ fn parse_call_item(item: Pair<Rule>, config: Option<&BuildConfig>) -> CompileRes
     let exp = match item.as_rule() {
         Rule::ident => Expression::VariableExpression {
             name: check!(
-                Ident::parse_from_pair(item.clone(), config),
+                ident::parse_from_pair(item.clone(), config),
                 return err(warnings, errors),
                 warnings,
                 errors
