@@ -1,8 +1,6 @@
 use super::*;
-use crate::parse_tree::AsmOp;
-use crate::semantic_analysis::ast_node::*;
-use crate::type_engine::*;
-use crate::Ident;
+
+use crate::{parse_tree::AsmOp, semantic_analysis::ast_node::*, Ident};
 
 #[derive(Clone, Debug)]
 pub(crate) struct ContractCallMetadata {
